<?php

namespace Drupal\ecc\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Serialization\Yaml;

/**
 * Defines the ECC type entity.
 *
 * @ConfigEntityType(
 *   id = "ecc_type",
 *   label = @Translation("ECC type"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\ecc\EccTypeListBuilder",
 *     "form" = {
 *       "add" = "Drupal\ecc\Form\EccTypeForm",
 *       "edit" = "Drupal\ecc\Form\EccTypeForm",
 *       "delete" = "Drupal\ecc\Form\EccTypeDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "ecc_type",
 *   admin_permission = "administer ecc type entities",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "title",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/structure/ecc/type/{ecc_type}",
 *     "add-form" = "/admin/structure/ecc/type/add",
 *     "edit-form" = "/admin/structure/ecc/type/{ecc_type}/edit",
 *     "delete-form" = "/admin/structure/ecc/type/{ecc_type}/delete",
 *     "collection" = "/admin/structure/ecc/type",
 *   }
 * )
 */
class EccType extends ConfigEntityBase {

  /**
   * The Ecc type ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Ecc type title.
   *
   * @var string
   */
  protected $title;

  /**
   * The Ecc type category.
   *
   * @var string
   */
  protected $category;

  /**
   * Does Ecc type exportable.
   *
   * @var string
   */
  protected $exportable;

  /**
   * The Ecc type fields_schema.
   *
   * @var string
   */
  protected $fields_schema;

  /**
   * Get form fields in array format.
   *
   * @return array
   *   Form fields.
   */
  public function getFormFields() {
    $fields_schema = $this->get('fields_schema');
    $fields_schema_decoded = Yaml::decode($fields_schema);

    return $fields_schema_decoded ?? [];
  }

  /**
   * Get category label.
   *
   * @return string
   *   Category label.
   */
  public function getCategoryLabel() {
    return $this->get('category');
  }

  /**
   * Define whether type is exportable.
   *
   * @return bool
   *   Exportable.
   */
  public function isExportable() {
    return $this->get('exportable');
  }

}
